﻿using Infragistics.Win.UltraWinGrid;
using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SummariesDisplaySampleApp
{
    public partial class Form1 : Form
    {
        #region Ctor
        public Form1()
        {
            InitializeComponent();
        }
        #endregion
        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraGrid1.DisplayLayout.Override.AllowRowSummaries = AllowRowSummaries.True;
            this.ultraGrid1.DataSource = InitializeData(25);
            this.ultraGrid1.AfterSortChange += UltraGrid1_AfterSortChange;


            this.ultraCombo1.DataSource = Enum.GetNames(typeof(SummaryDisplayAreas)).ToList();
            this.ultraCombo1.Value = SummaryDisplayAreas.Bottom.ToString();
        }

        #region Grid Event : AfterSortChanged
        private void UltraGrid1_AfterSortChange(object sender, BandEventArgs e)
        {
            DisplaySummaries();            
        }
        #endregion
        #region Grid Event : InitializeLayout
        private void ultraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            //Adding Custom Group By Comparer
            e.Layout.ViewStyleBand = ViewStyleBand.OutlookGroupBy;
            //e.Layout.Bands[0].SortedColumns.Clear();

            UltraGridColumn customerName = e.Layout.Bands[0].Columns["CustomerName"];
            e.Layout.Bands[0].SortedColumns.Add(customerName, false, true);
        }
        #endregion

        #region Method : DisplaySummaries
        private void DisplaySummaries()
        {
            SummaryDisplayAreas eArea = SummaryDisplayAreas.None;
            bool bIsGrouped = false;

            // Determine if any column is grouped
            foreach (UltraGridColumn col in this.ultraGrid1.DisplayLayout.Bands[0].Columns)
                if (col.IsGroupByColumn)
                    bIsGrouped = true;

            // Parse Combobox for Summary DisplayArea
            string sArea = ultraCombo1.Value as string;
            if (!String.IsNullOrEmpty(sArea))
                eArea = (SummaryDisplayAreas)Enum.Parse(typeof(SummaryDisplayAreas), sArea);

            // If any column is grouped then Set the SummaryDisplayArea otherwise Set it to None
            if (bIsGrouped)
                this.ultraGrid1.DisplayLayout.Override.SummaryDisplayArea = eArea;
            else
                this.ultraGrid1.DisplayLayout.Override.SummaryDisplayArea = SummaryDisplayAreas.None;
        }
        #endregion

        #region Method : InitializeData
        private BindingList<Customers> InitializeData(int count)
        {
            BindingList<Customers> retVal = new BindingList<Customers>();

            Customers cust = null;

            for (int i = 1; i < count; i++)
            {
                for (int j = 1; j < count; j++)
                {
                    // Initializing the data
                    cust = new Customers() { CustomerName = "Customer" + i, CustomerRank = j };
                    retVal.Add(cust);
                }
            }

            return retVal;
        }
        #endregion
        #region ComboEvent : ValueChanged
        private void ultraCombo1_ValueChanged(object sender, EventArgs e)
        {
            DisplaySummaries();
        }
        #endregion
        
    }
    

    #region Public Class:Customers
    public class Customers
    {
        public string CustomerName { get; set; }
        public int CustomerRank { get; set; }
    }
    #endregion

}

